@@ -935,32 +935,32 @@ while(T) {
   
   
   
-  testthat::test_that("the function returns a vector of words if string split is TRUE and the remove_stopwords parameter is a vector of user defined stop-words", {
-  
-    sample_stopwords = c("a", "this", "is")
-  
-    tmp = tokenize_transform_text(object = text_path, batches = NULL, read_file_delimiter = "\n", to_lower = TRUE, to_upper = FALSE, utf_locale = "", remove_char = "",
-  
-                             remove_punctuation_string = FALSE, remove_punctuation_vector = TRUE, remove_numbers = FALSE, trim_token = TRUE, split_string = TRUE,
-  
-                             split_separator = " \r\n\t.,;:()?!//", remove_stopwords = sample_stopwords, language = "english", min_num_char = 1, max_num_char = Inf, stemmer = NULL, min_n_gram = 1,
-  
-                             max_n_gram = 1, skip_n_gram = 1, skip_distance = 0, n_gram_delimiter = " ", concat_delimiter = NULL, path_2folder = "", stemmer_ngram = 4, stemmer_gamma = 0.0,
-  
-                             stemmer_truncate = 3, stemmer_batches = 1, threads = 1, vocabulary_path_file = NULL, verbose = FALSE)
-  
-    res_stpw = sum(!sample_stopwords %in% tmp$token) == 3
-  
-    res_tes = names(tmp) == 'token'  && length(tmp) == 1 && is.vector(tmp$token) && is.character(tmp$token) && class(tmp) == "tokenization and transformation" && res_stpw
-    
-    #-------------------------------------------------------------------- debug tests
-    cat("test-tokenization_transformation.R : test id", cnt_tsts, "\n")
-    
-    cnt_tsts <<- cnt_tsts + 1
-    #-------------------------------------------------------------------- 
-    
-    testthat::expect_true( res_tes  )
-  })
+  # testthat::test_that("the function returns a vector of words if string split is TRUE and the remove_stopwords parameter is a vector of user defined stop-words", {
+  # 
+  #   sample_stopwords = c("a", "this", "is")
+  # 
+  #   tmp = tokenize_transform_text(object = text_path, batches = NULL, read_file_delimiter = "\n", to_lower = TRUE, to_upper = FALSE, utf_locale = "", remove_char = "",
+  # 
+  #                            remove_punctuation_string = FALSE, remove_punctuation_vector = TRUE, remove_numbers = FALSE, trim_token = TRUE, split_string = TRUE,
+  # 
+  #                            split_separator = " \r\n\t.,;:()?!//", remove_stopwords = sample_stopwords, language = "english", min_num_char = 1, max_num_char = Inf, stemmer = NULL, min_n_gram = 1,
+  # 
+  #                            max_n_gram = 1, skip_n_gram = 1, skip_distance = 0, n_gram_delimiter = " ", concat_delimiter = NULL, path_2folder = "", stemmer_ngram = 4, stemmer_gamma = 0.0,
+  # 
+  #                            stemmer_truncate = 3, stemmer_batches = 1, threads = 1, vocabulary_path_file = NULL, verbose = FALSE)
+  # 
+  #   res_stpw = sum(!sample_stopwords %in% tmp$token) == 3
+  # 
+  #   res_tes = names(tmp) == 'token'  && length(tmp) == 1 && is.vector(tmp$token) && is.character(tmp$token) && class(tmp) == "tokenization and transformation" && res_stpw
+  #   
+  #   #-------------------------------------------------------------------- debug tests
+  #   cat("test-tokenization_transformation.R : test id", cnt_tsts, "\n")
+  #   
+  #   cnt_tsts <<- cnt_tsts + 1
+  #   #-------------------------------------------------------------------- 
+  #   
+  #   testthat::expect_true( res_tes  )
+  # })
   
   
   testthat::test_that("the function returns a vector of words if string split is TRUE and stemmer is porter2_stemmer", {
